"""
Python module generated from Java source file org.bukkit.block.EnchantingTable

Java source file obtained from artifact spigot-api version 1.21.2-R0.1-20241023.084343-5

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Nameable
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class EnchantingTable(TileState, Nameable):
    """
    Represents a captured state of an enchanting table.
    """


