"""
Python module generated from Java source file com.google.common.graph.GraphConstants

Java source file obtained from artifact guava version 32.1.2-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.graph import *
from typing import Any, Callable, Iterable, Tuple


class GraphConstants:
    """
    A utility class to hold various constants used by the Guava Graph library.
    """


